AdminLTE 3 | Dashboard 3

# Dashboard v3

### Online Store Visitors

View Report

820 Visitors Over Time

12.5% Since last week

This Week Last Week

### Products

Product | Price | Sales | More
--- | --- | --- | ---
Some Product | $13 USD | 12% 12,000 Sold |
Another Product | $29 USD | 0.5% 123,234 Sold |
Amazing Product | $1,230 USD | 3% 198 Sold |
Perfect Item NEW | $199 USD | 63% 87 Sold |

### Sales

View Report

$18,230.00 Sales Over Time

33.1% Since last month

This year Last year

### Online Store Overview

12% CONVERSION RATE

0.8% SALES RATE

1% REGISTRATION RATE